@@ -80,7 +80,7 @@ class SeedsAgent:
                 # TODO: ask for genesis block so seed can use this beacon as a relay
 
             except (ConnectionError, ConnectionResetError, ConnectionRefusedError,
-                    ConnectionAbortedError, TimeoutError, OSError):
+                    ConnectionAbortedError, TimeoutError, OSError) as ex:
                 logger.debug(f"{node_v4[0]}:{node_v4[1]} failed to connect")
             finally:
                 sleep(random.randint(1, 5))
