@@ -9,8 +9,7 @@ from decentnet.consensus.block_sizing import BLOCK_PREFIX_LENGTH_BYTES, MAXIMUM_
 from decentnet.consensus.byte_conversion_constants import ENDIAN_TYPE
 from decentnet.consensus.dev_constants import RUN_IN_DEBUG
 from decentnet.modules.logger.log import setup_logger
-from decentnet.modules.tcp.socket_functions import recv_all, set_sock_properties_common, \
-    set_sock_properties_ipv6
+from decentnet.modules.tcp.socket_functions import recv_all, set_sock_properties
 
 logger = logging.getLogger(__name__)
 
@@ -29,9 +28,7 @@ class TCPClient:
             else:
                 self.socket = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
                 self.socket.connect((self.host, self.port, 0, 0))
-                set_sock_properties_ipv6(self.socket)
-
-            set_sock_properties_common(self.socket)
+            set_sock_properties(self.socket)
             logger.debug(f"Connected on {self.socket.getsockname()}")
         else:
             peer_name = client_socket.getpeername()
