@@ -16,7 +16,7 @@ from decentnet.modules.req_queue.reques_queue import ReqQueue
 from decentnet.modules.tasks_base.consumer import Consumer
 from decentnet.modules.tasks_base.r2r_comm import R2RComm
 from decentnet.modules.tcp.db_functions import remove_alive_beam_from_db_w_pub_key
-from decentnet.modules.tcp.socket_functions import set_sock_properties_common, set_sock_properties_ipv6
+from decentnet.modules.tcp.socket_functions import set_sock_properties
 from decentnet.modules.timer.relay_counter import RelayCounter
 from decentnet.modules.timer.timer import Timer
 
@@ -35,10 +35,10 @@ class TCPServer:
             self.server.bind((self.host, self.port))
         else:
             self.server = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-            set_sock_properties_ipv6(self.server)
+            # Allow dual-stack (IPv4 + IPv6) connections
+            self.server.setsockopt(socket.IPPROTO_IPV6, socket.IPV6_V6ONLY, 1)
             self.server.bind((self.host, self.port, 0, 0))
 
-        set_sock_properties_common(self.server)
         self.clients = []
 
     @staticmethod
@@ -129,7 +129,7 @@ class TCPServer:
         while True:
             client_socket, client_address = self.server.accept()
 
-            set_sock_properties_common(client_socket)
+            set_sock_properties(client_socket)
 
             if client_address in (BLOCKED_IPV4 + BLOCKED_IPV6):
                 logger.debug(f"Blocked {client_address}, found in blacklist.")
