@@ -5,13 +5,13 @@ class Timer:
     start: float
 
     def __init__(self):
-        self.start = time.perf_counter() * 1000
+        self.start = time.perf_counter()
 
     def stop(self):
-        end = time.perf_counter() * 1000
+        end = time.perf_counter()
         dur = end - self.start
         return dur
 
     def seq_stop(self):
-        self.start = time.perf_counter() * 1000
+        self.start = time.perf_counter()
         return self.stop()
